;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "cfrs" "20250729.1422"
  "Child-frame based read-string."
  '((emacs    "26.1")
    (dash     "2.11.0")
    (s        "1.10.0")
    (posframe "0.6.0"))
  :url "https://github.com/Alexander-Miller/cfrs"
  :commit "981bddb3fb9fd9c58aed182e352975bd10ad74c8"
  :revdesc "981bddb3fb9f"
  :authors '(("Alexander Miller" . "alexanderm@web.de"))
  :maintainers '(("Alexander Miller" . "alexanderm@web.de")))
